=begin
[i]TIG (c) 2015[/i]  

All rights reserved.    

**TIG-LayersToList.rb**  

#Installation:  

Suitable for SketchUp Versions >= 2014...  
The RB file goes in the Plugins folder [restart Sketchup].   
Or much easier, no restart required !  
Use the Preferences > Extensions > Install button... on the RBZ archive.  

#Overview:  

A tool to write Layers' data to a file :  
Layer's by Name and the Layer's Colors RGB values.  

[i]Plugins|Extensions > TIG-LayersToList[/i]  

Makes a file with a line for each Layer Name and Color, in the format:  

[i]LayerName:R,G,B[/i]  

The ":" is the separator between the Layer's Name and its R,G,B values.  

The R,G,B Color values are separated by commas, and are integers 0 to 255.  
These represent the Red, Green, Blue values - the higher the number the more  
of that hue in the Color.  
Note that the Layer Color's 'A' alpha-transparency is not accessible in the  
Ruby API.  

The file is a plain text file of any name - obviously give it something  
that is meaningful to you.  

Run the tool...  

Chose the file-name...  by default it is "ModelName_Layers.txt",  
in the same folder as the model.  
The [i]LayerName:R,G,B[/i] data is written to the file.  
Layer names are sorted in order, but "Layer0" always comes first.  
The file is opened...  
  
Purpose:  

This file can be used in another Model in conjunction with the sibling tool  
"TIG-LayersFromList".  
You can edit the file before importing its data as desired.  

Version:  

1.0 20150531 First issue.  

=end
###
require('sketchup.rb')
###
module TIG
	module LayersToList
		### edit the layerName:R,G,B separator here...
		@separator = ":"
		### menu
		unless file_loaded?(__FILE__)
			UI.menu("Plugins").add_item("TIG-LayersToList"){ self.new() }
			file_loaded(__FILE__)
		end
		###
		def self.new()
			unless Sketchup.version.to_i >= 14
				UI.messagebox("TIG-LayersToList: Only works with SketchUp >= v2014 !")
				return nil
			end
			model = Sketchup.active_model
			layers = model.layers
			path = model.path
			if path.empty?
				dir = Dir.pwd
				tit = "Untitled"
			else
				dir = File.dirname(path)
				tit = model.title
			end
			file = UI.savepanel("TIG-LayersToList: Choose File-name/Directory...", dir, "#{tit}_Layers.txt")
			return nil unless file
			###
			ls = model.layers
			layers = ls.collect{|layer| layer.name }
			layers.delete("Layer0")
			layers = ["Layer0"] + layers.sort
		    layers.dup.each_with_index{|layer, i|
				color = ls[layer].color
				r = color.red
				g = color.green
				b = color.blue
				layers[i] = "#{layer}#{@separator}#{r},#{g},#{b}"
			}
			begin
				fio = File.open(file, "w")
				fio.puts(layers)
				fio.close
				UI.openURL("file:///#{file}")
				return true
			rescue
				UI.messagebox("TIG-LayersToList: Error opening file.\n#{file}\nCheck that it is not open in another application,\nand/or that you have permission to write to that destination folder...")
				return false
			end			
		end
	end
end#TIG
